@@ -18,22 +18,28 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Quadratic programming solvers in Python with a unified API"""
+"""Quadratic programming solvers in Python with a unified API."""
 
-from .exceptions import ProblemError
+from ._internals import available_solvers
+from .exceptions import (
+    NoSolverSelected,
+    ParamError,
+    ProblemError,
+    QPError,
+    SolverError,
+    SolverNotFound,
+)
 from .problem import Problem
 from .solution import Solution
 from .solve_ls import solve_ls
 from .solve_qp import solve_problem, solve_qp
-from .solve_safer_qp import solve_safer_qp
+from .solve_unconstrained import solve_unconstrained
 from .solvers import (
-    available_solvers,
     cvxopt_solve_qp,
     dense_solvers,
     ecos_solve_qp,
     gurobi_solve_qp,
     highs_solve_qp,
-    mosek_solve_qp,
     osqp_solve_qp,
     proxqp_solve_qp,
     qpoases_solve_qp,
@@ -42,14 +48,20 @@ from .solvers import (
     scs_solve_qp,
     sparse_solvers,
 )
+from .unsupported import mosek_solve_qp, nppro_solve_qp
 from .utils import print_matrix_vector
 
-__version__ = "2.7.4"
+__version__ = "3.1.0"
 
 __all__ = [
+    "NoSolverSelected",
+    "ParamError",
     "Problem",
     "ProblemError",
+    "QPError",
     "Solution",
+    "SolverError",
+    "SolverNotFound",
     "__version__",
     "available_solvers",
     "cvxopt_solve_qp",
@@ -58,6 +70,7 @@ __all__ = [
     "gurobi_solve_qp",
     "highs_solve_qp",
     "mosek_solve_qp",
+    "nppro_solve_qp",
     "osqp_solve_qp",
     "print_matrix_vector",
     "proxqp_solve_qp",
@@ -68,6 +81,6 @@ __all__ = [
     "solve_ls",
     "solve_problem",
     "solve_qp",
-    "solve_safer_qp",
+    "solve_unconstrained",
     "sparse_solvers",
 ]
