@@ -18,11 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solve linear least squares.
-"""
+"""Solve linear least squares."""
 
-import warnings
 from typing import Optional, Union
 
 import numpy as np
@@ -43,24 +40,24 @@ def solve_ls(
     W: Optional[Union[np.ndarray, spa.csc_matrix]] = None,
     solver: Optional[str] = None,
     initvals: Optional[np.ndarray] = None,
-    sym_proj: bool = False,
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a constrained weighted linear Least Squares problem defined as:
+    r"""Solve a constrained weighted linear Least Squares problem.
+
+    The linear least squares is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac12 \\| R x - s \\|^2_W
-                = \\frac12 (R x - s)^T W (R x - s) \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac12 \| R x - s \|^2_W
+                = \frac12 (R x - s)^T W (R x - s) \\
+            \mbox{subject to}
+                & G x \leq h          \\
+                & A x = b             \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
     using the QP solver selected by the ``solver`` keyword argument.
 
@@ -92,8 +89,6 @@ def solve_ls(
         :data:`qpsolvers.available_solvers`. This argument is mandatory.
     initvals :
         Vector of initial `x` values used to warm-start the solver.
-    sym_proj :
-        Set to `True` when the `R` matrix provided is not symmetric.
     verbose :
         Set to `True` to print out extra information.
 
@@ -102,20 +97,23 @@ def solve_ls(
     :
         Optimal solution if found, otherwise ``None``.
 
+    Note
+    ----
+    In least squares, the matrix :math:`R` should be symmetric. Many
+    solvers (including CVXOPT, OSQP and quadprog) leverage this property and
+    may return unintended results when it is not the case. You can set
+    project :math:`R` on its symmetric part by:
+
+    .. code:: python
+
+        R = 0.5 * (R + R.transpose())
+
     Notes
     -----
     Extra keyword arguments given to this function are forwarded to the
     underlying solvers. For example, OSQP has a setting `eps_abs` which we can
     provide by ``solve_ls(R, s, G, h, solver='osqp', eps_abs=1e-4)``.
     """
-    if sym_proj:
-        R = 0.5 * (R + R.transpose())
-        warnings.warn(
-            "The `sym_proj` feature is deprecated "
-            "and will be removed in qpsolvers v3.0",
-            DeprecationWarning,
-            stacklevel=2,
-        )
     WR: Union[np.ndarray, spa.csc_matrix] = R if W is None else W @ R
     P = R.T @ WR
     q = -(s.T @ WR)
@@ -132,7 +130,6 @@ def solve_ls(
         ub,
         solver=solver,
         initvals=initvals,
-        sym_proj=False,
         verbose=verbose,
         **kwargs,
     )
