@@ -18,11 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solve quadratic programs.
-"""
+"""Solve quadratic programs."""
 
-import warnings
 from typing import Optional, Union
 
 import numpy as np
@@ -45,23 +42,23 @@ def solve_qp(
     ub: Optional[np.ndarray] = None,
     solver: Optional[str] = None,
     initvals: Optional[np.ndarray] = None,
-    sym_proj: bool = False,
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a quadratic program defined as:
+    r"""Solve a quadratic program.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
     using the QP solver selected by the ``solver`` keyword argument.
 
@@ -88,10 +85,6 @@ def solve_qp(
         :data:`qpsolvers.available_solvers`. This argument is mandatory.
     initvals :
         Primal candidate vector :math:`x` values used to warm-start the solver.
-    sym_proj :
-        Set to ``True`` to project the cost matrix :math:`P` to its symmetric
-        part. Some solvers assume :math:`P` is symmetric and will return
-        unintended results if it is not the case.
     verbose :
         Set to ``True`` to print out extra information.
 
@@ -100,8 +93,11 @@ def solve_qp(
     In quadratic programming, the matrix :math:`P` should be symmetric. Many
     solvers (including CVXOPT, OSQP and quadprog) leverage this property and
     may return unintended results when it is not the case. You can set
-    ``sym_proj=True`` to project :math:`P` on its symmetric part, at the cost
-    of a little computation time.
+    project :math:`P` on its symmetric part by:
+
+    .. code:: python
+
+        P = 0.5 * (P + P.transpose())
 
     Returns
     -------
@@ -113,14 +109,20 @@ def solve_qp(
     NoSolverSelected
         If the ``solver`` keyword argument is not set.
 
-    SolverNotFound
-        If the requested solver is not in :data:`qpsolvers.available_solvers`.
+    ParamError
+        If any solver parameter is incorrect.
 
-    ValueError
+    ProblemError
         If the problem is not correctly defined. For instance, if the solver
         requires a definite cost matrix but the provided matrix :math:`P` is
         not.
 
+    SolverError
+        If the solver failed during its execution.
+
+    SolverNotFound
+        If the requested solver is not in :data:`qpsolvers.available_solvers`.
+
     Notes
     -----
     Extra keyword arguments given to this function are forwarded to the
@@ -139,14 +141,6 @@ def solve_qp(
             "Set the `solver` keyword argument to one of the "
             f"available solvers in {available_solvers}"
         )
-    if sym_proj:
-        P = 0.5 * (P + P.transpose())
-        warnings.warn(
-            "The `sym_proj` feature is deprecated "
-            "and will be removed in qpsolvers v3.0",
-            DeprecationWarning,
-            stacklevel=2,
-        )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = solve_problem(problem, solver, initvals, verbose, **kwargs)
     return solution.x
