@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `CVXOPT <https://cvxopt.org/>`__.
+"""Solver interface for `CVXOPT <https://cvxopt.org/>`__.
 
 CVXOPT is a free software package for convex optimization in Python. Its main
 purpose is to make the development of software for convex optimization
@@ -37,6 +36,7 @@ import scipy.sparse as spa
 from cvxopt.solvers import qp
 
 from ..conversions import linear_from_box_inequalities, split_dual_linear_box
+from ..exceptions import ProblemError, SolverError
 from ..problem import Problem
 from ..solution import Solution
 
@@ -47,8 +47,7 @@ __infty__ = 1e10  # 1e20 tends to yield division-by-zero errors
 def __to_cvxopt(
     M: Union[np.ndarray, spa.csc_matrix]
 ) -> Union[cvxopt.matrix, cvxopt.spmatrix]:
-    """
-    Convert matrix to CVXOPT format.
+    """Convert matrix to CVXOPT format.
 
     Parameters
     ----------
@@ -76,8 +75,7 @@ def cvxopt_solve_problem(
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a quadratic program using `CVXOPT <http://cvxopt.org/>`_.
+    r"""Solve a quadratic program using CVXOPT.
 
     Parameters
     ----------
@@ -95,6 +93,14 @@ def cvxopt_solve_problem(
     :
         Solution to the QP, if found, otherwise ``None``.
 
+    Raises
+    ------
+    ProblemError
+        If the CVXOPT rank assumption is not satisfied.
+
+    SolverError
+        If CVXOPT failed with an error.
+
     Note
     ----
     .. _CVXOPT rank assumptions:
@@ -103,11 +109,11 @@ def cvxopt_solve_problem(
 
     .. math::
 
-        \\begin{split}\\begin{array}{cc}
-        \\mathrm{rank}(A) = p
+        \begin{split}\begin{array}{cc}
+        \mathrm{rank}(A) = p
         &
-        \\mathrm{rank}([P\\ A^T\\ G^T]) = n
-        \\end{array}\\end{split}
+        \mathrm{rank}([P\ A^T\ G^T]) = n
+        \end{array}\end{split}
 
     where :math:`p` is the number of rows of :math:`A` and :math:`n` is the
     number of optimization variables. See the "Rank assumptions" paragraph in
@@ -166,10 +172,17 @@ def cvxopt_solve_problem(
     kwargs["show_progress"] = verbose
     original_options = cvxopt.solvers.options
     cvxopt.solvers.options = kwargs
-    res = qp(*args, solver=solver, initvals=initvals_dict, **constraints)
+    try:
+        res = qp(*args, solver=solver, initvals=initvals_dict, **constraints)
+    except ValueError as exception:
+        error = str(exception)
+        if "Rank(A)" in error:
+            raise ProblemError(error) from exception
+        raise SolverError(error) from exception
     cvxopt.solvers.options = original_options
 
     solution = Solution(problem)
+    solution.extras = res
     if "optimal" not in res["status"]:
         return solution
     solution.x = np.array(res["x"]).reshape((q.shape[0],))
@@ -181,7 +194,6 @@ def cvxopt_solve_problem(
         solution.z = z
         solution.z_box = z_box
     solution.obj = res["primal objective"]
-    solution.extras = res
     return solution
 
 
@@ -199,40 +211,41 @@ def cvxopt_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using CVXOPT.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `CVXOPT <http://cvxopt.org/>`_.
+    It is solved using `CVXOPT <http://cvxopt.org/>`__.
 
     Parameters
     ----------
     P :
         Symmetric cost matrix. Together with :math:`A` and :math:`G`, it should
-        satisfy :math:`\\mathrm{rank}([P\\ A^T\\ G^T]) = n`, see the rank
+        satisfy :math:`\mathrm{rank}([P\ A^T\ G^T]) = n`, see the rank
         assumptions below.
     q :
         Cost vector.
     G :
         Linear inequality matrix. Together with :math:`P` and :math:`A`, it
-        should satisfy :math:`\\mathrm{rank}([P\\ A^T\\ G^T]) = n`, see the
+        should satisfy :math:`\mathrm{rank}([P\ A^T\ G^T]) = n`, see the
         rank assumptions below.
     h :
         Linear inequality vector.
     A :
         Linear equality constraint matrix. It needs to be full row rank, and
         together with :math:`P` and :math:`G` satisfy
-        :math:`\\mathrm{rank}([P\\ A^T\\ G^T]) = n`. See the rank assumptions
+        :math:`\mathrm{rank}([P\ A^T\ G^T]) = n`. See the rank assumptions
         below.
     b :
         Linear equality constraint vector.
@@ -251,6 +264,14 @@ def cvxopt_solve_qp(
     -------
     :
         Primal solution to the QP, if found, otherwise ``None``.
+
+    Raises
+    ------
+    ProblemError
+        If the CVXOPT rank assumption is not satisfied.
+
+    SolverError
+        If CVXOPT failed with an error.
     """
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = cvxopt_solve_problem(
