@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `HiGHS <https://github.com/ERGO-Code/HiGHS>`__.
+"""Solver interface for `HiGHS <https://github.com/ERGO-Code/HiGHS>`__.
 
 HiGHS is an open source, serial and parallel solver for large scale sparse
 linear programming (LP), mixed-integer programming (MIP), and quadratic
@@ -36,14 +35,13 @@ import highspy
 import numpy as np
 import scipy.sparse as spa
 
-from ..conversions import warn_about_sparse_conversion
+from ..conversions import ensure_sparse_matrices
 from ..problem import Problem
 from ..solution import Solution
 
 
 def __set_hessian(model: highspy.HighsModel, P: spa.csc_matrix) -> None:
-    """
-    Set Hessian :math:`Q` of the cost :math:`(1/2) x^T Q x + c^T x`.
+    """Set Hessian :math:`Q` of the cost :math:`(1/2) x^T Q x + c^T x`.
 
     Parameters
     ----------
@@ -64,11 +62,12 @@ def __set_columns(
     lb: Optional[np.ndarray] = None,
     ub: Optional[np.ndarray] = None,
 ) -> None:
-    """
-    Set columns of the model, that is:
+    r"""Set columns of the model.
+
+    Columns consist of:
 
     - Linear part :math:`c` of the cost :math:`(1/2) x^T Q x + c^T x`
-    - Box inequalities :math:`l \\leq x \\leq u``
+    - Box inequalities :math:`l \leq x \leq u``
 
     Parameters
     ----------
@@ -96,8 +95,7 @@ def __set_rows(
     A: Optional[spa.csc_matrix] = None,
     b: Optional[np.ndarray] = None,
 ) -> None:
-    """
-    Set rows :math:`L \\leq A x \\leq U`` of the model.
+    r"""Set rows :math:`L \leq A x \leq U`` of the model.
 
     Parameters
     ----------
@@ -146,9 +144,7 @@ def highs_solve_problem(
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a quadratic program using `HiGHS
-    <https://github.com/ERGO-Code/HiGHS>`__.
+    """Solve a quadratic program using HiGHS.
 
     Parameters
     ----------
@@ -187,19 +183,11 @@ def highs_solve_problem(
     for more information on the solver.
     """
     P, q, G, h, A, b, lb, ub = problem.unpack()
-    if isinstance(P, np.ndarray):
-        warn_about_sparse_conversion("P")
-        P = spa.csc_matrix(P)
-    if isinstance(G, np.ndarray):
-        warn_about_sparse_conversion("G")
-        G = spa.csc_matrix(G)
-    if isinstance(A, np.ndarray):
-        warn_about_sparse_conversion("A")
-        A = spa.csc_matrix(A)
+    P, G, A = ensure_sparse_matrices(P, G, A)
     if initvals is not None:
         warnings.warn(
             "HiGHS: warm-start values are not available for this solver, "
-            "see: https://github.com/stephane-caron/qpsolvers/issues/94"
+            "see: https://github.com/qpsolvers/qpsolvers/issues/94"
         )
 
     model = highspy.HighsModel()
@@ -252,21 +240,22 @@ def highs_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using HiGHS.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `HiGHS <https://github.com/ERGO-Code/HiGHS>`__.
+    It is solved using `HiGHS <https://github.com/ERGO-Code/HiGHS>`__.
 
     Parameters
     ----------
