@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `OSQP <https://osqp.org/>`__.
+"""Solver interface for `OSQP <https://osqp.org/>`__.
 
 The OSQP solver implements an Operator-Splitting method for large-scale convex
 quadratic programming. It is designed for both dense and sparse problems, and
@@ -39,7 +38,7 @@ import scipy.sparse as spa
 from osqp import OSQP
 from scipy.sparse import csc_matrix
 
-from ..conversions import warn_about_sparse_conversion
+from ..conversions import ensure_sparse_matrices
 from ..problem import Problem
 from ..solution import Solution
 
@@ -50,9 +49,7 @@ def osqp_solve_problem(
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a quadratic program using `OSQP
-    <https://github.com/oxfordcontrol/osqp>`__.
+    """Solve a quadratic program using OSQP.
 
     Parameters
     ----------
@@ -123,15 +120,7 @@ def osqp_solve_problem(
     overview of solver tolerances.
     """
     P, q, G, h, A, b, lb, ub = problem.unpack()
-    if isinstance(P, np.ndarray):
-        warn_about_sparse_conversion("P")
-        P = csc_matrix(P)
-    if isinstance(G, np.ndarray):
-        warn_about_sparse_conversion("G")
-        G = csc_matrix(G)
-    if isinstance(A, np.ndarray):
-        warn_about_sparse_conversion("A")
-        A = csc_matrix(A)
+    P, G, A = ensure_sparse_matrices(P, G, A)
 
     A_osqp = None
     l_osqp = None
@@ -162,6 +151,11 @@ def osqp_solve_problem(
     success_status = osqp.constant("OSQP_SOLVED")
 
     solution = Solution(problem)
+    solution.extras = {
+        "dual_inf_cert": res.dual_inf_cert,
+        "info": res.info,
+        "prim_inf_cert": res.prim_inf_cert,
+    }
     if res.info.status_val != success_status:
         warnings.warn(f"OSQP exited with status '{res.info.status}'")
         return solution
@@ -174,11 +168,6 @@ def osqp_solve_problem(
         solution.y = res.y[m : m + meq]
     if lb is not None or ub is not None:
         solution.z_box = res.y[m + meq :]
-    solution.extras = {
-        "dual_inf_cert": res.dual_inf_cert,
-        "info": res.info,
-        "prim_inf_cert": res.prim_inf_cert,
-    }
     return solution
 
 
@@ -195,20 +184,22 @@ def osqp_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using OSQP.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `OSQP <https://github.com/oxfordcontrol/osqp>`_.
+    It is solved using `OSQP <https://github.com/oxfordcontrol/osqp>`__.
 
     Parameters
     ----------
