@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `qpOASES <https://github.com/coin-or/qpOASES>`__.
+"""Solver interface for `qpOASES <https://github.com/coin-or/qpOASES>`__.
 
 qpOASES is an open-source C++ implementation of the online active set strategy,
 which was inspired by observations from the field of parametric quadratic
@@ -44,7 +43,7 @@ from qpoases import PyQProblem as QProblem
 from qpoases import PyQProblemB as QProblemB
 from qpoases import PyReturnValue as ReturnValue
 
-from ..exceptions import ProblemError
+from ..exceptions import ParamError, ProblemError
 from ..problem import Problem
 from ..solution import Solution
 
@@ -63,8 +62,7 @@ RET_INIT_FAILED_REGULARISATION = 39
 
 
 def __clamp_infinities(v: Optional[np.ndarray]):
-    """
-    Replace infinite values in an array by big finite ones.
+    """Replace infinite values in an array by big finite ones.
 
     Note
     ----
@@ -81,8 +79,7 @@ def __prepare_options(
     predefined_options: Optional[str],
     **kwargs,
 ) -> Options:
-    """
-    Prepare options for qpOASES.
+    """Prepare options for qpOASES.
 
     Parameters
     ----------
@@ -96,6 +93,11 @@ def __prepare_options(
     -------
     :
         Options for qpOASES.
+
+    Raises
+    ------
+    ParamError
+        If predefined options are not a valid choice for qpOASES.
     """
     options = Options()
 
@@ -111,7 +113,7 @@ def __prepare_options(
     elif predefined_options == "reliable":
         options.setToReliable()
     else:
-        raise ValueError(
+        raise ParamError(
             f"unknown qpOASES pre-defined options {predefined_options}'"
         )
 
@@ -129,8 +131,7 @@ def __convert_inequalities(
     A: Optional[np.ndarray] = None,
     b: Optional[np.ndarray] = None,
 ) -> Tuple[np.ndarray, Optional[np.ndarray], np.ndarray]:
-    """
-    Convert linear constraints to qpOASES format.
+    """Convert linear constraints to qpOASES format.
 
     Parameters
     ----------
@@ -178,9 +179,7 @@ def qpoases_solve_problem(
     predefined_options: Optional[str] = None,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a quadratic program using `qpOASES
-    <https://github.com/coin-or/qpOASES>`__.
+    """Solve a quadratic program using qpOASES.
 
     Parameters
     ----------
@@ -247,7 +246,7 @@ def qpoases_solve_problem(
     options.
     """
     if initvals is not None:
-        print("qpOASES: note that warm-start values ignored by wrapper")
+        warnings.warn("qpOASES: warm-start values are ignored")
     P, q, G, h, A, b, lb, ub = problem.unpack()
 
     n = P.shape[0]
@@ -279,6 +278,9 @@ def qpoases_solve_problem(
         raise ProblemError("problem has sparse matrices") from error
 
     solution = Solution(problem)
+    solution.extras = {
+        "nWSR": n_wsr[0],
+    }
     if RET_INIT_FAILED <= return_value <= RET_INIT_FAILED_REGULARISATION:
         return solution
     if return_value == ReturnValue.MAX_NWSR_REACHED:
@@ -298,9 +300,6 @@ def qpoases_solve_problem(
     if A is not None:
         solution.y = -z_opt[n + m : n + m + A.shape[0]]
     solution.obj = qp.getObjVal()
-    solution.extras = {
-        "nWSR": n_wsr[0],
-    }
     return solution
 
 
@@ -320,21 +319,22 @@ def qpoases_solve_qp(
     predefined_options: Optional[str] = None,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using qpOASES.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `qpOASES <https://github.com/coin-or/qpOASES>`__.
+    It is solved using `qpOASES <https://github.com/coin-or/qpOASES>`__.
 
     Parameters
     ----------
