@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `SCS <https://www.cvxgrp.org/scs/>`__.
+"""Solver interface for `SCS <https://www.cvxgrp.org/scs/>`__.
 
 SCS (Splitting Conic Solver) is a numerical optimization package for solving
 large-scale convex quadratic cone problems, which is a general class of
@@ -28,18 +27,18 @@ work, consider citing the corresponding paper [ODonoghue2021]_.
 """
 
 import warnings
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Dict, Optional, Union
 
 import numpy as np
 import scipy.sparse as spa
 from numpy import ndarray
 from scipy.sparse import csc_matrix
-from scipy.sparse.linalg import lsqr
 from scs import solve
 
-from ..conversions import warn_about_sparse_conversion
+from ..conversions import ensure_sparse_matrices
 from ..problem import Problem
 from ..solution import Solution
+from ..solve_unconstrained import solve_unconstrained
 
 # See https://www.cvxgrp.org/scs/api/exit_flags.html#exit-flags
 __status_val_meaning__ = {
@@ -63,8 +62,7 @@ def __add_box_cone(
     cone: Dict[str, Any],
     data: Dict[str, Any],
 ) -> None:
-    """
-    Add box cone to the problem.
+    """Add box cone to the problem.
 
     Parameters
     ----------
@@ -96,65 +94,13 @@ def __add_box_cone(
     )
 
 
-def __solve_unconstrained(problem: Problem) -> Solution:
-    """
-    Solve an unconstrained quadratic program, warning if it is unbounded.
-
-    Parameters
-    ----------
-    problem :
-        Unconstrained quadratic program.
-
-    Returns
-    -------
-    :
-        Solution to the unconstrained QP, if it is bounded.
-
-    Raises
-    ------
-    ValueError
-        If the quadratic program is not unbounded below.
-    """
-    P, q, _, _, _, _, _, _ = problem.unpack()
-    solution = Solution(problem)
-    solution.x = lsqr(P, -q)[0]
-    cost_check = np.linalg.norm(P @ solution.x + q)
-    if cost_check > 1e-8:
-        raise ValueError(
-            f"problem is unbounded below (cost_check={cost_check:.1e}), "
-            "q has component in the nullspace of P"
-        )
-    return solution
-
-
-def __ensure_sparse_matrices(
-    P: Union[ndarray, csc_matrix],
-    G: Optional[Union[ndarray, csc_matrix]],
-    A: Optional[Union[ndarray, csc_matrix]],
-) -> Tuple[csc_matrix, Optional[csc_matrix], Optional[csc_matrix]]:
-    """
-    Make sure matrices are sparse.
-    """
-    if isinstance(P, ndarray):
-        warn_about_sparse_conversion("P")
-        P = csc_matrix(P)
-    if isinstance(G, ndarray):
-        warn_about_sparse_conversion("G")
-        G = csc_matrix(G)
-    if isinstance(A, ndarray):
-        warn_about_sparse_conversion("A")
-        A = csc_matrix(A)
-    return P, G, A
-
-
 def scs_solve_problem(
     problem: Problem,
     initvals: Optional[ndarray] = None,
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a quadratic program using `SCS <https://github.com/cvxgrp/scs>`__.
+    """Solve a quadratic program using SCS.
 
     Parameters
     ----------
@@ -211,7 +157,7 @@ def scs_solve_problem(
     all available settings.
     """
     P, q, G, h, A, b, lb, ub = problem.unpack()
-    P, G, A = __ensure_sparse_matrices(P, G, A)
+    P, G, A = ensure_sparse_matrices(P, G, A)
     n = P.shape[0]
 
     data: Dict[str, Any] = {"P": P, "c": q}
@@ -233,7 +179,7 @@ def scs_solve_problem(
         data["b"] = h
         cone["l"] = h.shape[0]  # positive cone
     elif lb is None and ub is None:  # no constraint
-        return __solve_unconstrained(problem)
+        return solve_unconstrained(problem)
     if lb is not None or ub is not None:
         __add_box_cone(n, lb, ub, cone, data)
     kwargs["verbose"] = verbose
@@ -271,21 +217,22 @@ def scs_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using SCS.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using `SCS <https://github.com/cvxgrp/scs>`__.
+    It is solved using `SCS <https://github.com/cvxgrp/scs>`__.
 
     Parameters
     ----------
