@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests for Solution class."""
+
 import unittest
 
 import numpy as np
@@ -28,14 +30,11 @@ from .problems import get_sd3310_problem
 
 
 class TestSolution(unittest.TestCase):
+    """Test fixture for solutions."""
 
-    """
-    Test fixture for solutions.
-    """
-
-    def test_empty(self):
+    def test_found_default(self):
         solution = Solution(get_sd3310_problem())
-        self.assertTrue(solution.is_empty)
+        self.assertFalse(solution.found)
 
     def test_residuals(self):
         problem = get_sd3310_problem()
