@@ -18,9 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Tests for the `solve_problem` function.
-"""
+"""Unit tests for the `solve_problem` function."""
 
 import math
 import unittest
@@ -41,10 +39,7 @@ from .solved_problems import (
 
 
 class TestSolveProblem(unittest.TestCase):
-
-    """
-    Test fixture for primal and dual solutions of a variety of quadratic
-    programs.
+    """Test fixture for primal and dual solutions of a variety of problems.
 
     Notes
     -----
@@ -56,8 +51,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_qpsut01(solver: str):
-        """
-        Get test function for a given solver.
+        """Get test function for a given solver.
 
         Parameters
         ----------
@@ -97,8 +91,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_qpsut02(solver: str):
-        """
-        Get test function for a given solver.
+        """Get test function for a given solver.
 
         Parameters
         ----------
@@ -125,7 +118,7 @@ class TestSolveProblem(unittest.TestCase):
                 else 1e-5
                 if solver in ["highs", "osqp"]
                 else 5e-7
-                if solver == "qpswift"
+                if solver in ["clarabel", "qpswift"]
                 else 1e-7
                 if solver == "gurobi"
                 else 1e-8
@@ -139,8 +132,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_qpsut03(solver: str):
-        """
-        Get test function for a given solver.
+        """Get test function for a given solver.
 
         Parameters
         ----------
@@ -216,8 +208,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_maros_meszaros_qptest(solver):
-        """
-        Get test function for the QPTEST problem.
+        """Get test function for the QPTEST problem.
 
         Parameters
         ----------
@@ -264,8 +255,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_infinite_box_bounds(solver):
-        """
-        Problem with some infinite box bounds.
+        """Problem with some infinite box bounds.
 
         Parameters
         ----------
@@ -291,8 +281,7 @@ class TestSolveProblem(unittest.TestCase):
 
     @staticmethod
     def get_test_infinite_linear_bounds(solver):
-        """
-        Problem with some infinite linear bounds.
+        """Problem with some infinite linear bounds.
 
         Parameters
         ----------
@@ -345,26 +334,29 @@ for solver in available_solvers:
             f"test_qpsut05_{solver}",
             TestSolveProblem.get_test_qpsut05(solver),
         )
-    if solver not in ["ecos", "qpswift"]:
-        # See https://github.com/stephane-caron/qpsolvers/issues/159
-        # See https://github.com/stephane-caron/qpsolvers/issues/160
+    if solver not in ["clarabel", "ecos", "qpswift"]:
+        # clarabel: https://github.com/oxfordcontrol/Clarabel.rs/issues/14
+        # See https://github.com/qpsolvers/qpsolvers/issues/159
+        # See https://github.com/qpsolvers/qpsolvers/issues/160
         setattr(
             TestSolveProblem,
             f"test_maros_meszaros_qptest_{solver}",
             TestSolveProblem.get_test_maros_meszaros_qptest(solver),
         )
-    if solver not in ["ecos", "qpswift"]:
-        # See https://github.com/stephane-caron/qpsolvers/issues/159
-        # See https://github.com/stephane-caron/qpsolvers/issues/160
+    if solver not in ["clarabel", "ecos", "qpswift"]:
+        # clarabel: https://github.com/oxfordcontrol/Clarabel.rs/issues/14
+        # See https://github.com/qpsolvers/qpsolvers/issues/159
+        # See https://github.com/qpsolvers/qpsolvers/issues/160
         setattr(
             TestSolveProblem,
             f"test_infinite_box_bounds_{solver}",
             TestSolveProblem.get_test_infinite_box_bounds(solver),
         )
-    if solver not in ["ecos", "qpswift", "scs"]:
-        # See https://github.com/stephane-caron/qpsolvers/issues/159
-        # See https://github.com/stephane-caron/qpsolvers/issues/160
-        # See https://github.com/stephane-caron/qpsolvers/issues/161
+    if solver not in ["clarabel", "ecos", "qpswift", "scs"]:
+        # clarabel: https://github.com/oxfordcontrol/Clarabel.rs/issues/14
+        # See https://github.com/qpsolvers/qpsolvers/issues/159
+        # See https://github.com/qpsolvers/qpsolvers/issues/160
+        # See https://github.com/qpsolvers/qpsolvers/issues/161
         setattr(
             TestSolveProblem,
             f"test_infinite_linear_bounds_{solver}",
