@@ -18,17 +18,14 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
+"""Unit tests with unfeasible problems."""
+
 import unittest
 import warnings
 
 from numpy import array, dot
 
-from qpsolvers import (
-    available_solvers,
-    dense_solvers,
-    solve_qp,
-    solve_safer_qp,
-)
+from qpsolvers import available_solvers, solve_qp
 
 
 class UnfeasibleProblem(unittest.TestCase):
@@ -44,7 +41,7 @@ class UnfeasibleProblem(unittest.TestCase):
         """
         warnings.simplefilter("ignore", category=UserWarning)
 
-    def get_dense_problem(self):
+    def get_unfeasible_problem(self):
         """
         Get problem as a sextuple of values to unpack.
 
@@ -89,37 +86,12 @@ class UnfeasibleProblem(unittest.TestCase):
         """
 
         def test(self):
-            P, q, G, h, A, b = self.get_dense_problem()
+            P, q, G, h, A, b = self.get_unfeasible_problem()
             x = solve_qp(P, q, G, h, A, b, solver=solver)
             self.assertIsNone(x)
 
         return test
 
-    @staticmethod
-    def get_test_safer(solver):
-        """
-        Closure of test function for a given solver.
-
-        Parameters
-        ----------
-        solver : string
-            Name of the solver to test.
-
-        Returns
-        -------
-        test : function
-            Test function for that solver.
-        """
-
-        def test(self):
-            P, q, G, h, _, _ = self.get_dense_problem()
-            G[0] = 0
-            h[0] = -10000.0
-            x = solve_safer_qp(P, q, G, h, sr=1e-2, solver=solver)
-            self.assertIsNone(x)
-
-        return test
-
 
 # Generate test fixtures for each solver
 for solver in available_solvers:
@@ -132,9 +104,3 @@ for solver in available_solvers:
         "test_{}".format(solver),
         UnfeasibleProblem.get_test(solver),
     )
-    if solver in dense_solvers:
-        setattr(
-            UnfeasibleProblem,
-            "test_safer_{}".format(solver),
-            UnfeasibleProblem.get_test_safer(solver),
-        )
